<template>
  <div class="editor-container">
    <div :id="id"></div>
  </div>
</template>
<script>
import ClassicEditor from '.././../../public/editor-video/ckeditor'
import UploadAdapter from './uploadAdapter'
function UploadAdapterPlugin (editor) {
  editor.plugins.get('FileRepository').createUploadAdapter = (loader) => {
    return new UploadAdapter(loader)
  }
}
export default {
  name: 'editor',
  props: {
    content: {
      type: String,
      default: ''
    },
    id: {
      default: 'editor'
    }
  },
  data () {
    return {
      editor: null
    }
  },
  watch: {
    content: {
      handler () {
        this.content && this.editor && this.editor.setData(this.content)
      },
      immediate: true
    }
  },
  mounted () {
    this.$nextTick(() => {
      this.init()
    })
  },
  methods: {
    init () {
      ClassicEditor.create(document.querySelector(`#${this.id}`), {
        extraPlugins: [UploadAdapterPlugin]
      })
        .then(editor => {
          this.editor = editor
          this.content && this.editor && this.editor.setData(this.content)
        })
        .catch(error => {
          console.error('There was a problem initializing the editor.', error)
        })
    },
    getData () {
      let content = this.editor.getData()
      content = content.replace(/<video /g, '<video controls muted ')
      return content
    }
  }
}
</script>
<style lang="scss">
.ck-content {
  height:500px;
  font-size: 16px;
}
.editor-container .ck.ck-editor__editable_inline {
  border: 1px solid var(--ck-color-toolbar-border);
  // border-top: none;
  padding: 0 30px;
}
</style>
